Colour Difference
=================

Delta E
-------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    delta_E
    DELTA_E_METHODS

CIE 1976
--------

``colour.difference``

.. currentmodule:: colour.difference

.. autosummary::
    :toctree: generated/

    JND_CIE1976
    delta_E_CIE1976

CIE 1994
--------

``colour.difference``

.. currentmodule:: colour.difference

.. autosummary::
    :toctree: generated/

    delta_E_CIE1994

CIE 2000
--------

``colour.difference``

.. currentmodule:: colour.difference

.. autosummary::
    :toctree: generated/

    delta_E_CIE2000

CMC
---

``colour.difference``

.. currentmodule:: colour.difference

.. autosummary::
    :toctree: generated/

    delta_E_CMC

ITP
---

``colour.difference``

.. currentmodule:: colour.difference

.. autosummary::
    :toctree: generated/

    delta_E_ITP

Luo, Cui and Li (2006)
----------------------

``colour.difference``

.. currentmodule:: colour.difference

.. autosummary::
    :toctree: generated/

    delta_E_CAM02LCD
    delta_E_CAM02SCD
    delta_E_CAM02UCS

Li, Li, Wang, Zu, Luo, Cui, Melgosa, Brill and Pointer (2017)
-------------------------------------------------------------

``colour.difference``

.. currentmodule:: colour.difference

.. autosummary::
    :toctree: generated/

    delta_E_CAM16LCD
    delta_E_CAM16SCD
    delta_E_CAM16UCS

DIN99
-----

``colour.difference``

.. currentmodule:: colour.difference

.. autosummary::
    :toctree: generated/

    delta_E_DIN99

Standardized Residual Sum of Squares (STRESS) Index
---------------------------------------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    index_stress
    INDEX_STRESS_METHODS

``colour.difference``

.. currentmodule:: colour.difference

.. autosummary::
    :toctree: generated/

    index_stress_Garcia2007

Huang et al. (2015) Power-Functions
-----------------------------------

``colour.difference``

.. currentmodule:: colour.difference

.. autosummary::
    :toctree: generated/

    power_function_Huang2015
